a.treeviewLink64 {
color:#000;
cursor:pointer;
font-family:verdana,sans-serif;
font-size:64px;
height:88px;
white-space:nowrap;
vertical-align:top;
}
a.treeviewLink64:hover {
color:blue;
cursor:pointer;
font-family:verdana,sans-serif;
font-size:64px;
height:88px;
white-space:nowrap;
vertical-align:top;
}
table.treeview64 {
background-color:#FFF;
color:#000;
}
td.captionBorder64 {
border-bottom:1px;
border-bottom-style:dashed;
color:#000;
font-family:verdana, sans-serif;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.clasicLastMinusNode64 {
background-image:url('/style/Crystal/64/html-menu-treeview/clasicLastMinusNode.gif');
background-repeat:no-repeat;
cursor:pointer;
height:88px;
vertical-align:top;
}
td.clasicLastPlusNode64 {
background-image:url('/style/Crystal/64/html-menu-treeview/clasicLastPlusNode.gif');
background-repeat:no-repeat;
cursor:pointer;
height:88px;
vertical-align:top;
}
td.clasicMinusNode64 {
background-image:url('/style/Crystal/64/html-menu-treeview/clasicMinusNode.gif');
background-repeat:no-repeat;
cursor:pointer;
vertical-align:top;
}
td.clasicPlusNode64 {
background-image:url('/style/Crystal/64/html-menu-treeview/clasicPlusNode.gif');
background-repeat:no-repeat;
cursor:pointer;
height:88px;
vertical-align:top;
}
td.columnsFolder64,td.columnsNode64,td.columnsLastNode64 {
font-family:verdana, sans-serif;
font-size:64px;
height:88px;
white-space:nowrap;
vertical-align:top;
}
td.columnsFolderBorder64,td.columnsNodeBorder64,td.columnsLastNodeBorder64 {
border-left:1px;
border-left-style:dashed;
color:#000;
height:176px;
font-family:verdana, sans-serif;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.folderClosed64 {
background-image:url('/style/Crystal/64/html-menu-treeview/folderClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.folderCrystal64 {
background-image:url('/style/Crystal/64/html-menu-treeview/folderCrystal.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.folderCrystalClosed64 {
background-image:url('/style/Crystal/64/html-menu-treeview/folderCrystalClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.folderFavorite64 {
background-image:url('/style/Crystal/64/html-menu-treeview/folderFavorite.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.folderFavoriteClosed64 {
background-image:url('/style/Crystal/64/html-menu-treeview/folderFavoriteClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.folderGray64 {
background-image:url('/style/Crystal/64/html-menu-treeview/folderGray.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.folderGrayClosed64 {
background-image:url('/style/Crystal/64/html-menu-treeview/folderGrayClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.folderGreen64 {
background-image:url('/style/Crystal/64/html-menu-treeview/folderGreen.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.folderGreenClosed64 {
background-image:url('/style/Crystal/64/html-menu-treeview/folderGreenClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.folderHtml64 {
background-image:url('/style/Crystal/64/html-menu-treeview/folderHtml.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.folderHtmlClosed64 {
background-image:url('/style/Crystal/64/html-menu-treeview/folderHtmlClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.folderImage64 {
background-image:url('/style/Crystal/64/html-menu-treeview/folderImage.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.folderImageClosed64 {
background-image:url('/style/Crystal/64/html-menu-treeview/folderImageClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.folderImportant64 {
background-image:url('/style/Crystal/64/html-menu-treeview/folderImportant.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.folderImportantClosed64 {
background-image:url('/style/Crystal/64/html-menu-treeview/folderImportantClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.folderLocked64 {
background-image:url('/style/Crystal/64/html-menu-treeview/folderLocked.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.folderLockedClosed64 {
background-image:url('/style/Crystal/64/html-menu-treeview/folderLockedClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.folderMan64 {
background-image:url('/style/Crystal/64/html-menu-treeview/folderMan.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.folderManClosed64 {
background-image:url('/style/Crystal/64/html-menu-treeview/folderManClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.folderOpen64 {
background-image:url('/style/Crystal/64/html-menu-treeview/folderOpen.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.folderOrange64 {
background-image:url('/style/Crystal/64/html-menu-treeview/folderOrange.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.folderOrangeClosed64 {
background-image:url('/style/Crystal/64/html-menu-treeview/folderOrangeClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.folderPrint64 {
background-image:url('/style/Crystal/64/html-menu-treeview/folderPrint.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.folderPrintClosed64 {
background-image:url('/style/Crystal/64/html-menu-treeview/folderPrintClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.folderRed64 {
background-image:url('/style/Crystal/64/html-menu-treeview/folderRed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.folderRedClosed64 {
background-image:url('/style/Crystal/64/html-menu-treeview/folderRedClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:64px;
height:88px;
vertical-align:top;
}
td.folderSound64 {
background-image:url('/style/Crystal/64/html-menu-treeview/folderSound.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.folderSoundClosed64 {
background-image:url('/style/Crystal/64/html-menu-treeview/folderSoundClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.folderTar64 {
background-image:url('/style/Crystal/64/html-menu-treeview/folderTar.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.folderTarClosed64 {
background-image:url('/style/Crystal/64/html-menu-treeview/folderTarClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.folderText64 {
background-image:url('/style/Crystal/64/html-menu-treeview/folderText.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.folderTextClosed64 {
background-image:url('/style/Crystal/64/html-menu-treeview/folderTextClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.folderVideo64 {
background-image:url('/style/Crystal/64/html-menu-treeview/folderVideo.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.folderVideoClosed64 {
background-image:url('/style/Crystal/64/html-menu-treeview/folderVideoClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.folderViolet64 {
background-image:url('/style/Crystal/64/html-menu-treeview/folderViolet.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.folderVioletClosed64 {
background-image:url('/style/Crystal/64/html-menu-treeview/folderVioletClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.folderYellow64 {
background-image:url('/style/Crystal/64/html-menu-treeview/folderYellow.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.folderYellowClosed64 {
background-image:url('/style/Crystal/64/html-menu-treeview/folderYellowClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:64px;
height:88px;
vertical-align:top;
white-space:nowrap;
}
td.lastMinusNode64 {
background-image:url('/style/Crystal/64/html-menu-treeview/lastMinusNode.gif');
background-repeat:no-repeat;
cursor:pointer;
white-space:nowrap;
vertical-align:top;
}
td.lastNode64 {
background-image:url('/style/Crystal/64/html-menu-treeview/lastNode.gif');
background-repeat:no-repeat;
cursor:pointer;
font-size:64px;
height:88px;
white-space:nowrap;
vertical-align:top;
}
td.lastPlusNode64 {
background-image:url('/style/Crystal/64/html-menu-treeview/lastPlusNode.gif');
background-repeat:no-repeat;
cursor:pointer;
height:88px;
white-space:nowrap;
vertical-align:top;
}
td.minusNode64 {
background-image:url('/style/Crystal/64/html-menu-treeview/minusNode.gif');
background-repeat:no-repeat;
cursor:pointer;
white-space:nowrap;
vertical-align:top;
}
td.node64 {
background-image:url('/style/Crystal/64/html-menu-treeview/node.gif');
background-repeat:repeat-y;
cursor:pointer;
font-size:64px;
height:88px;
text-align:left;
white-space:nowrap;
vertical-align:top;
}
td.plusNode64 {
background-image:url('/style/Crystal/64/html-menu-treeview/plusNode.gif');
background-repeat:no-repeat;
cursor:pointer;
white-space:nowrap;
vertical-align:top;
}
td.submenuDeco64 {
background-image:url('/style/Crystal/64/html-menu-treeview/vertLine.gif');
background-repeat:repeat-y;
}