var folderClosed = new Image(16,16);
folderClosed.src='/style/Crystal/16/html-menu-treeview/folderClosed.gif';
var plusNode = new Image(16,16);
plusNode.src='/style/Crystal/16/html-menu-treeview/plusNode.gif';
var lastPlusNode = new Image(16,16);
lastPlusNode.src='/style/Crystal/16/html-menu-treeview/lastPlusNode.gif';
var clasicPlusNode = new Image(16,16);
clasicPlusNode.src='/style/Crystal/16/html-menu-treeview/clasicPlusNode.gif';
var clasicLastPlusNode = new Image(16,16);
clasicLastPlusNode.src='/style/Crystal/16/html-menu-treeview/clasicLastPlusNode.gif';
var folderManClosed = new Image(16,16);
folderManClosed.src='/style/Crystal/16/html-menu-treeview/folderManClosed.gif';
var folderGrayClosed = new Image(16,16);
folderGrayClosed.src='/style/Crystal/16/html-menu-treeview/folderGrayClosed.gif';
var folderGreenClosed = new Image(16,16);
folderGreenClosed.src='/style/Crystal/16/html-menu-treeview/folderGreenClosed.gif';
var folderRedClosed = new Image(16,16);
folderRedClosed.src='/style/Crystal/16/html-menu-treeview/folderRedClosed.gif';
var folderViolet = new Image(16,16);
folderViolet.src='/style/Crystal/16/html-menu-treeview/folderViolet.gif';
var folderYellowClosed = new Image(16,16);
folderYellowClosed.src='/style/Crystal/16/html-menu-treeview/folderYellowClosed.gif';
var folderOrangeClosed = new Image(16,16);
folderOrangeClosed.src='/style/Crystal/16/html-menu-treeview/folderOrangeClosed.gif';
var folderManClosed = new Image(16,16);
folderManClosed.src='/style/Crystal/16/html-menu-treeview/folderManClosed.gif';
var folderSentMailClosed = new Image(16,16);
folderSentMailClosed.src='/style/Crystal/16/html-menu-treeview/folderSentMailClosed.gif';
var folderHtmlClosed = new Image(16,16);
folderHtmlClosed.src='/style/Crystal/16/html-menu-treeview/folderHtmlClosed.gif';
var folderFavoriteClosed = new Image(16,16);
folderFavoriteClosed.src='/style/Crystal/16/html-menu-treeview/folderFavoriteClosed.gif';
var folderTextClosed = new Image(16,16);
folderTextClosed.src='/style/Crystal/16/html-menu-treeview/folderTextClosed.gif';
var folderLockedClosed = new Image(16,16);
folderLockedClosed.src='/style/Crystal/16/html-menu-treeview/folderLockedClosed.gif';
var folderCrystalClosed = new Image(16,16);
folderCrystalClosed.src='/style/Crystal/16/html-menu-treeview/folderCrystalClosed.gif';
var folderVideoClosed = new Image(16,16);
folderVideoClosed.src='/style/Crystal/16/html-menu-treeview/folderVideoClosed.gif';
var folderPrintClosed = new Image(16,16);
folderPrintClosed.src='/style/Crystal/16/html-menu-treeview/folderPrintClosed.gif';
var folderImageClosed = new Image(16,16);
folderImageClosed.src='/style/Crystal/16/html-menu-treeview/folderImageClosed.gif';
var folderSoundClosed = new Image(16,16);
folderSoundClosed.src='/style/Crystal/16/html-menu-treeview/folderSoundClosed.gif';
var folderImportantClosed = new Image(16,16);
folderImportantClosed.src='/style/Crystal/16/html-menu-treeview/folderImportantClosed.gif';
var folderTarClosed = new Image(16,16);
folderTarClosed.src='/style/Crystal/16/html-menu-treeview/folderTarClosed.gif';
var folderClosed22 = new Image(22,22);
folderClosed22.src='/style/Crystal/22/html-menu-treeview/folderClosed.gif';
var plusNode22 = new Image(22,22);
plusNode22.src='/style/Crystal/22/html-menu-treeview/plusNode.gif';
var lastPlusNode22 = new Image(22,22);
lastPlusNode22.src='/style/Crystal/22/html-menu-treeview/lastPlusNode.gif';
var clasicPlusNode22 = new Image(22,22);
clasicPlusNode22.src='/style/Crystal/22/html-menu-treeview/clasicPlusNode.gif';
var clasicLastPlusNode22 = new Image(22,22);
clasicLastPlusNode22.src='/style/Crystal/22/html-menu-treeview/clasicLastPlusNode.gif';
var folderGrayClosed22 = new Image(22,22);
folderGrayClosed22.src='/style/Crystal/22/html-menu-treeview/folderGrayClosed.gif';
var folderGreenClosed22 = new Image(22,22);
folderGreenClosed22.src='/style/Crystal/22/html-menu-treeview/folderGreenClosed.gif';
var folderRedClosed22 = new Image(22,22);
folderRedClosed22.src='/style/Crystal/22/html-menu-treeview/folderRedClosed.gif';
var folderViolet22 = new Image(22,22);
folderViolet22.src='/style/Crystal/22/html-menu-treeview/folderViolet.gif';
var folderYellowClosed22 = new Image(22,22);
folderYellowClosed22.src='/style/Crystal/22/html-menu-treeview/folderYellowClosed.gif';
var folderOrangeClosed22 = new Image(22,22);
folderOrangeClosed22.src='/style/Crystal/22/html-menu-treeview/folderOrangeClosed.gif';
var folderPrintClosed22 = new Image(22,22);
folderPrintClosed22.src='/style/Crystal/22/html-menu-treeview/folderPrintClosed.gif';
var folderClosed32 = new Image(32,32);
folderClosed32.src='/style/Crystal/32/html-menu-treeview/folderClosed.gif';
var plusNode32 = new Image(32,32);
plusNode32.src='/style/Crystal/32/html-menu-treeview/plusNode.gif';
var lastPlusNode32 = new Image(32,32);
lastPlusNode32.src='/style/Crystal/32/html-menu-treeview/lastPlusNode.gif';
var clasicPlusNode32 = new Image(32,32);
clasicPlusNode32.src='/style/Crystal/32/html-menu-treeview/clasicPlusNode.gif';
var clasicLastPlusNode32 = new Image(32,32);
clasicLastPlusNode32.src='/style/Crystal/32/html-menu-treeview/clasicLastPlusNode.gif';
var folderManClosed32 = new Image(32,32);
folderManClosed32.src='/style/Crystal/32/html-menu-treeview/folderManClosed.gif';
var folderGrayClosed32 = new Image(32,32);
folderGrayClosed32.src='/style/Crystal/32/html-menu-treeview/folderGrayClosed.gif';
var folderGreenClosed32 = new Image(32,32);
folderGreenClosed32.src='/style/Crystal/32/html-menu-treeview/folderGreenClosed.gif';
var folderRedClosed32 = new Image(32,32);
folderRedClosed32.src='/style/Crystal/32/html-menu-treeview/folderRedClosed.gif';
var folderViolet32 = new Image(32,32);
folderViolet32.src='/style/Crystal/32/html-menu-treeview/folderViolet.gif';
var folderYellowClosed32 = new Image(32,32);
folderYellowClosed32.src='/style/Crystal/32/html-menu-treeview/folderYellowClosed.gif';
var folderOrangeClosed32 = new Image(32,32);
folderOrangeClosed32.src='/style/Crystal/32/html-menu-treeview/folderOrangeClosed.gif';
var folderManClosed32 = new Image(32,32);
folderManClosed32.src='/style/Crystal/32/html-menu-treeview/folderManClosed.gif';
var folderHtmlClosed32 = new Image(32,32);
folderHtmlClosed32.src='/style/Crystal/32/html-menu-treeview/folderHtmlClosed.gif';
var folderFavoriteClosed32 = new Image(32,32);
folderFavoriteClosed32.src='/style/Crystal/32/html-menu-treeview/folderFavoriteClosed.gif';
var folderTextClosed32 = new Image(32,32);
folderTextClosed32.src='/style/Crystal/32/html-menu-treeview/folderTextClosed.gif';
var folderLockedClosed32 = new Image(32,32);
folderLockedClosed32.src='/style/Crystal/32/html-menu-treeview/folderLockedClosed.gif';
var folderCrystalClosed32 = new Image(32,32);
folderCrystalClosed32.src='/style/Crystal/32/html-menu-treeview/folderCrystalClosed.gif';
var folderVideoClosed32 = new Image(32,32);
folderVideoClosed32.src='/style/Crystal/32/html-menu-treeview/folderVideoClosed.gif';
var folderPrintClosed32 = new Image(32,32);
folderPrintClosed32.src='/style/Crystal/32/html-menu-treeview/folderPrintClosed.gif';
var folderImageClosed32 = new Image(32,32);
folderImageClosed32.src='/style/Crystal/32/html-menu-treeview/folderImageClosed.gif';
var folderSoundClosed32 = new Image(32,32);
folderSoundClosed32.src='/style/Crystal/32/html-menu-treeview/folderSoundClosed.gif';
var folderImportantClosed32 = new Image(32,32);
folderImportantClosed32.src='/style/Crystal/32/html-menu-treeview/folderImportantClosed.gif';
var folderTarClosed32 = new Image(32,32);
folderTarClosed32.src='/style/Crystal/32/html-menu-treeview/folderTarClosed.gif';
var folderClosed48 = new Image(48,48);
folderClosed48.src='/style/Crystal/48/html-menu-treeview/folderClosed.gif';
var plusNode48 = new Image(48,48);
plusNode48.src='/style/Crystal/48/html-menu-treeview/plusNode.gif';
var lastPlusNode48 = new Image(48,48);
lastPlusNode48.src='/style/Crystal/48/html-menu-treeview/lastPlusNode.gif';
var clasicPlusNode48 = new Image(48,48);
clasicPlusNode48.src='/style/Crystal/48/html-menu-treeview/clasicPlusNode.gif';
var clasicLastPlusNode48 = new Image(48,48);
clasicLastPlusNode48.src='/style/Crystal/48/html-menu-treeview/clasicLastPlusNode.gif';
var folderManClosed48 = new Image(48,48);
folderManClosed48.src='/style/Crystal/48/html-menu-treeview/folderManClosed.gif';
var folderGrayClosed48 = new Image(48,48);
folderGrayClosed48.src='/style/Crystal/48/html-menu-treeview/folderGrayClosed.gif';
var folderGreenClosed48 = new Image(48,48);
folderGreenClosed48.src='/style/Crystal/48/html-menu-treeview/folderGreenClosed.gif';
var folderRedClosed48 = new Image(48,48);
folderRedClosed48.src='/style/Crystal/48/html-menu-treeview/folderRedClosed.gif';
var folderViolet48 = new Image(48,48);
folderViolet48.src='/style/Crystal/48/html-menu-treeview/folderViolet.gif';
var folderYellowClosed48 = new Image(48,48);
folderYellowClosed48.src='/style/Crystal/48/html-menu-treeview/folderYellowClosed.gif';
var folderOrangeClosed48 = new Image(48,48);
folderOrangeClosed48.src='/style/Crystal/48/html-menu-treeview/folderOrangeClosed.gif';
var folderManClosed48 = new Image(48,48);
folderManClosed48.src='/style/Crystal/48/html-menu-treeview/folderManClosed.gif';
var folderHtmlClosed48 = new Image(48,48);
folderHtmlClosed48.src='/style/Crystal/48/html-menu-treeview/folderHtmlClosed.gif';
var folderFavoriteClosed48 = new Image(48,48);
folderFavoriteClosed48.src='/style/Crystal/48/html-menu-treeview/folderFavoriteClosed.gif';
var folderTextClosed48 = new Image(48,48);
folderTextClosed48.src='/style/Crystal/48/html-menu-treeview/folderTextClosed.gif';
var folderLockedClosed48 = new Image(48,48);
folderLockedClosed48.src='/style/Crystal/48/html-menu-treeview/folderLockedClosed.gif';
var folderCrystalClosed48 = new Image(48,48);
folderCrystalClosed48.src='/style/Crystal/48/html-menu-treeview/folderCrystalClosed.gif';
var folderVideoClosed48 = new Image(48,48);
folderVideoClosed48.src='/style/Crystal/48/html-menu-treeview/folderVideoClosed.gif';
var folderPrintClosed48 = new Image(48,48);
folderPrintClosed48.src='/style/Crystal/48/html-menu-treeview/folderPrintClosed.gif';
var folderImageClosed48 = new Image(48,48);
folderImageClosed48.src='/style/Crystal/48/html-menu-treeview/folderImageClosed.gif';
var folderSoundClosed48 = new Image(48,48);
folderSoundClosed48.src='/style/Crystal/48/html-menu-treeview/folderSoundClosed.gif';
var folderImportantClosed48 = new Image(48,48);
folderImportantClosed48.src='/style/Crystal/48/html-menu-treeview/folderImportantClosed.gif';
var folderTarClosed48 = new Image(48,48);
folderTarClosed48.src='/style/Crystal/48/html-menu-treeview/folderTarClosed.gif';
var folderClosed64 = new Image(64,64);
folderClosed64.src='/style/Crystal/64/html-menu-treeview/folderClosed.gif';
var plusNode64 = new Image(64,64);
plusNode64.src='/style/Crystal/64/html-menu-treeview/plusNode.gif';
var lastPlusNode64 = new Image(64,64);
lastPlusNode64.src='/style/Crystal/64/html-menu-treeview/lastPlusNode.gif';
var clasicPlusNode64 = new Image(64,64);
clasicPlusNode64.src='/style/Crystal/64/html-menu-treeview/clasicPlusNode.gif';
var clasicLastPlusNode64 = new Image(64,64);
clasicLastPlusNode64.src='/style/Crystal/64/html-menu-treeview/clasicLastPlusNode.gif';
var folderManClosed64 = new Image(64,64);
folderManClosed64.src='/style/Crystal/64/html-menu-treeview/folderManClosed.gif';
var folderGrayClosed64 = new Image(64,64);
folderGrayClosed64.src='/style/Crystal/64/html-menu-treeview/folderGrayClosed.gif';
var folderGreenClosed64 = new Image(64,64);
folderGreenClosed64.src='/style/Crystal/64/html-menu-treeview/folderGreenClosed.gif';
var folderRedClosed64 = new Image(64,64);
folderRedClosed64.src='/style/Crystal/64/html-menu-treeview/folderRedClosed.gif';
var folderViolet64 = new Image(64,64);
folderViolet64.src='/style/Crystal/64/html-menu-treeview/folderViolet.gif';
var folderYellowClosed64 = new Image(64,64);
folderYellowClosed64.src='/style/Crystal/64/html-menu-treeview/folderYellowClosed.gif';
var folderOrangeClosed64 = new Image(64,64);
folderOrangeClosed64.src='/style/Crystal/64/html-menu-treeview/folderOrangeClosed.gif';
var folderManClosed64 = new Image(64,64);
folderManClosed64.src='/style/Crystal/64/html-menu-treeview/folderManClosed.gif';
var folderHtmlClosed64 = new Image(64,64);
folderHtmlClosed64.src='/style/Crystal/64/html-menu-treeview/folderHtmlClosed.gif';
var folderFavoriteClosed64 = new Image(64,64);
folderFavoriteClosed64.src='/style/Crystal/64/html-menu-treeview/folderFavoriteClosed.gif';
var folderTextClosed64 = new Image(64,64);
folderTextClosed64.src='/style/Crystal/64/html-menu-treeview/folderTextClosed.gif';
var folderLockedClosed64 = new Image(64,64);
folderLockedClosed64.src='/style/Crystal/64/html-menu-treeview/folderLockedClosed.gif';
var folderCrystalClosed64 = new Image(64,64);
folderCrystalClosed64.src='/style/Crystal/64/html-menu-treeview/folderCrystalClosed.gif';
var folderVideoClosed64 = new Image(64,64);
folderVideoClosed64.src='/style/Crystal/64/html-menu-treeview/folderVideoClosed.gif';
var folderPrintClosed64 = new Image(64,64);
folderPrintClosed64.src='/style/Crystal/64/html-menu-treeview/folderPrintClosed.gif';
var folderImageClosed64 = new Image(64,64);
folderImageClosed64.src='/style/Crystal/64/html-menu-treeview/folderImageClosed.gif';
var folderSoundClosed64 = new Image(64,64);
folderSoundClosed64.src='/style/Crystal/64/html-menu-treeview/folderSoundClosed.gif';
var folderImportantClosed64 = new Image(64,64);
folderImportantClosed64.src='/style/Crystal/64/html-menu-treeview/folderImportantClosed.gif';
var folderTarClosed64 = new Image(64,64);
folderTarClosed64.src='/style/Crystal/64/html-menu-treeview/folderTarClosed.gif';
var folderClosed128 = new Image(128,128);
folderClosed128.src='/style/Crystal/128/html-menu-treeview/folderClosed.gif';
var plusNode128 = new Image(128,128);
plusNode128.src='/style/Crystal/128/html-menu-treeview/plusNode.gif';
var lastPlusNode128 = new Image(128,128);
lastPlusNode128.src='/style/Crystal/128/html-menu-treeview/lastPlusNode.gif';
var clasicPlusNode128 = new Image(128,128);
clasicPlusNode128.src='/style/Crystal/128/html-menu-treeview/clasicPlusNode.gif';
var clasicLastPlusNode128 = new Image(128,128);
clasicLastPlusNode128.src='/style/Crystal/128/html-menu-treeview/clasicLastPlusNode.gif';
var folderManClosed128 = new Image(128,128);
folderManClosed128.src='/style/Crystal/128/html-menu-treeview/folderManClosed.gif';
var folderGrayClosed128 = new Image(128,128);
folderGrayClosed128.src='/style/Crystal/128/html-menu-treeview/folderGrayClosed.gif';
var folderGreenClosed128 = new Image(128,128);
folderGreenClosed128.src='/style/Crystal/128/html-menu-treeview/folderGreenClosed.gif';
var folderRedClosed128 = new Image(128,128);
folderRedClosed128.src='/style/Crystal/128/html-menu-treeview/folderRedClosed.gif';
var folderViolet128 = new Image(128,128);
folderViolet128.src='/style/Crystal/128/html-menu-treeview/folderViolet.gif';
var folderYellowClosed128 = new Image(128,128);
folderYellowClosed128.src='/style/Crystal/128/html-menu-treeview/folderYellowClosed.gif';
var folderOrangeClosed128 = new Image(128,128);
folderOrangeClosed128.src='/style/Crystal/128/html-menu-treeview/folderOrangeClosed.gif';
var folderManClosed128 = new Image(128,128);
folderManClosed128.src='/style/Crystal/128/html-menu-treeview/folderManClosed.gif';
var folderHtmlClosed128 = new Image(128,128);
folderHtmlClosed128.src='/style/Crystal/128/html-menu-treeview/folderHtmlClosed.gif';
var folderFavoriteClosed128 = new Image(128,128);
folderFavoriteClosed128.src='/style/Crystal/128/html-menu-treeview/folderFavoriteClosed.gif';
var folderTextClosed128 = new Image(128,128);
folderTextClosed128.src='/style/Crystal/128/html-menu-treeview/folderTextClosed.gif';
var folderLockedClosed128 = new Image(128,128);
folderLockedClosed128.src='/style/Crystal/128/html-menu-treeview/folderLockedClosed.gif';
var folderCrystalClosed128 = new Image(128,128);
folderCrystalClosed128.src='/style/Crystal/128/html-menu-treeview/folderCrystalClosed.gif';
var folderVideoClosed128 = new Image(128,128);
folderVideoClosed128.src='/style/Crystal/128/html-menu-treeview/folderVideoClosed.gif';
var folderPrintClosed128 = new Image(128,128);
folderPrintClosed128.src='/style/Crystal/128/html-menu-treeview/folderPrintClosed.gif';
var folderImageClosed128 = new Image(128,128);
folderImageClosed128.src='/style/Crystal/128/html-menu-treeview/folderImageClosed.gif';
var folderSoundClosed128 = new Image(128,128);
folderSoundClosed128.src='/style/Crystal/128/html-menu-treeview/folderSoundClosed.gif';
var folderImportantClosed128 = new Image(128,128);
folderImportantClosed128.src='/style/Crystal/128/html-menu-treeview/folderImportantClosed.gif';
var folderTarClosed128 = new Image(128,128);
folderTarClosed128.src='/style/Crystal/128/html-menu-treeview/folderTarClosed.gif';